@@ -152,7 +152,9 @@ class BetterJSONStorage:
 
             if self._changed:
                 self._changed = False
+                self._handle.seek(0)
                 self._handle.write(compress(dumps(self._data)))
+                self._handle.truncate()
 
         self._shutdown_lock.release()
 
